@@ -10,29 +10,31 @@
 #
 import sys
 from zipfile import ZipFile
-from zipfile import BadZipfile
+from zipfile import BadZipFile
 
 # The VBA project file we want to extract.
-vba_filename = 'vbaProject.bin'
+vba_filename = "vbaProject.bin"
 
 # Get the xlsm file name from the commandline.
 if len(sys.argv) > 1:
     xlsm_file = sys.argv[1]
 else:
-    print("\nUtility to extract a vbaProject.bin binary from an Excel 2007+ "
-          "xlsm macro file for insertion into an XlsxWriter file."
-          "\n"
-          "See: https://xlsxwriter.readthedocs.io/working_with_macros.html\n"
-          "\n"
-          "Usage: vba_extract file.xlsm\n")
+    print(
+        "\nUtility to extract a vbaProject.bin binary from an Excel 2007+ "
+        "xlsm macro file for insertion into an XlsxWriter file."
+        "\n"
+        "See: https://xlsxwriter.readthedocs.io/working_with_macros.html\n"
+        "\n"
+        "Usage: vba_extract file.xlsm\n"
+    )
     exit()
 
 try:
     # Open the Excel xlsm file as a zip file.
-    xlsm_zip = ZipFile(xlsm_file, 'r')
+    xlsm_zip = ZipFile(xlsm_file, "r")
 
     # Read the xl/vbaProject.bin file.
-    vba_data = xlsm_zip.read('xl/' + vba_filename)
+    vba_data = xlsm_zip.read("xl/" + vba_filename)
 
     # Write the vba data to a local file.
     vba_file = open(vba_filename, "wb")
@@ -49,7 +51,7 @@ except KeyError as e:
     print("File may not be an Excel xlsm macro file: '%s'" % xlsm_file)
     exit()
 
-except BadZipfile as e:
+except BadZipFile as e:
     # Usually if the file is an xls file and not an xlsm file.
     print("File error: %s: '%s'" % (str(e), xlsm_file))
     print("File may not be an Excel xlsm macro file.")
