@@ -2,6 +2,6 @@
 # SPDX-License-Identifier: BSD-2-Clause
 # Copyright 2013-2023, John McNamara, jmcnamara@cpan.org
 #
-__version__ = '3.0.8'
+__version__ = "3.1.0"
 __VERSION__ = __version__
-from .workbook import Workbook
+from .workbook import Workbook  # noqa
