@@ -3,7 +3,7 @@
 # ChartBar - A class for writing the Excel XLSX Bar charts.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright 2013-2022, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from . import chart
@@ -33,31 +33,32 @@ class ChartBar(chart.Chart):
         if options is None:
             options = {}
 
-        self.subtype = options.get('subtype')
+        self.subtype = options.get("subtype")
 
         if not self.subtype:
-            self.subtype = 'clustered'
+            self.subtype = "clustered"
 
-        self.cat_axis_position = 'l'
-        self.val_axis_position = 'b'
+        self.cat_axis_position = "l"
+        self.val_axis_position = "b"
         self.horiz_val_axis = 0
         self.horiz_cat_axis = 1
         self.show_crosses = 0
 
         # Override and reset the default axis values.
-        self.x_axis['defaults']['major_gridlines'] = {'visible': 1}
-        self.y_axis['defaults']['major_gridlines'] = {'visible': 0}
+        self.x_axis["defaults"]["major_gridlines"] = {"visible": 1}
+        self.y_axis["defaults"]["major_gridlines"] = {"visible": 0}
 
-        if self.subtype == 'percent_stacked':
-            self.x_axis['defaults']['num_format'] = '0%'
+        if self.subtype == "percent_stacked":
+            self.x_axis["defaults"]["num_format"] = "0%"
 
         # Set the available data label positions for this chart type.
-        self.label_position_default = 'outside_end'
+        self.label_position_default = "outside_end"
         self.label_positions = {
-            'center': 'ctr',
-            'inside_base': 'inBase',
-            'inside_end': 'inEnd',
-            'outside_end': 'outEnd'}
+            "center": "ctr",
+            "inside_base": "inBase",
+            "inside_end": "inEnd",
+            "outside_end": "outEnd",
+        }
 
         self.set_x_axis({})
         self.set_y_axis({})
@@ -81,7 +82,7 @@ class ChartBar(chart.Chart):
             return
 
         if not chart.is_secondary:
-            warn('Charts combined with Bar charts must be on a secondary axis')
+            warn("Charts combined with Bar charts must be on a secondary axis")
 
         self.combined = chart
 
@@ -93,14 +94,14 @@ class ChartBar(chart.Chart):
 
     def _write_chart_type(self, args):
         # Override the virtual superclass method with a chart specific method.
-        if args['primary_axes']:
+        if args["primary_axes"]:
             # Reverse X and Y axes for Bar charts.
             tmp = self.y_axis
             self.y_axis = self.x_axis
             self.x_axis = tmp
 
-            if self.y2_axis['position'] == 'r':
-                self.y2_axis['position'] = 't'
+            if self.y2_axis["position"] == "r":
+                self.y2_axis["position"] = "t"
 
         # Write the c:barChart element.
         self._write_bar_chart(args)
@@ -108,7 +109,7 @@ class ChartBar(chart.Chart):
     def _write_bar_chart(self, args):
         # Write the <c:barChart> element.
 
-        if args['primary_axes']:
+        if args["primary_axes"]:
             series = self._get_primary_axes_series()
         else:
             series = self._get_secondary_axes_series()
@@ -117,15 +118,15 @@ class ChartBar(chart.Chart):
             return
 
         subtype = self.subtype
-        if subtype == 'percent_stacked':
-            subtype = 'percentStacked'
+        if subtype == "percent_stacked":
+            subtype = "percentStacked"
 
         # Set a default overlap for stacked charts.
-        if 'stacked' in self.subtype:
+        if "stacked" in self.subtype:
             if self.series_overlap_1 is None:
                 self.series_overlap_1 = 100
 
-        self._xml_start_tag('c:barChart')
+        self._xml_start_tag("c:barChart")
 
         # Write the c:barDir element.
         self._write_bar_dir()
@@ -138,13 +139,13 @@ class ChartBar(chart.Chart):
             self._write_ser(data)
 
         # Write the c:gapWidth element.
-        if args['primary_axes']:
+        if args["primary_axes"]:
             self._write_gap_width(self.series_gap_1)
         else:
             self._write_gap_width(self.series_gap_2)
 
         # Write the c:overlap element.
-        if args['primary_axes']:
+        if args["primary_axes"]:
             self._write_overlap(self.series_overlap_1)
         else:
             self._write_overlap(self.series_overlap_2)
@@ -152,7 +153,7 @@ class ChartBar(chart.Chart):
         # Write the c:axId elements
         self._write_axis_ids(args)
 
-        self._xml_end_tag('c:barChart')
+        self._xml_end_tag("c:barChart")
 
     ###########################################################################
     #
@@ -162,11 +163,11 @@ class ChartBar(chart.Chart):
 
     def _write_bar_dir(self):
         # Write the <c:barDir> element.
-        val = 'bar'
+        val = "bar"
 
-        attributes = [('val', val)]
+        attributes = [("val", val)]
 
-        self._xml_empty_tag('c:barDir', attributes)
+        self._xml_empty_tag("c:barDir", attributes)
 
     def _write_err_dir(self, val):
         # Overridden from Chart class since it is not used in Bar charts.
