@@ -87,7 +87,7 @@ class Packager(object):
 
         super(Packager, self).__init__()
 
-        self.tmpdir = ''
+        self.tmpdir = ""
         self.in_memory = False
         self.workbook = None
         self.worksheet_count = 0
@@ -174,7 +174,7 @@ class Packager(object):
         # Write the workbook.xml file.
         workbook = self.workbook
 
-        workbook._set_xml_writer(self._filename('xl/workbook.xml'))
+        workbook._set_xml_writer(self._filename("xl/workbook.xml"))
         workbook._assemble_xml_file()
 
     def _write_worksheet_files(self):
@@ -188,8 +188,9 @@ class Packager(object):
                 worksheet._opt_reopen()
                 worksheet._write_single_row()
 
-            worksheet._set_xml_writer(self._filename('xl/worksheets/sheet'
-                                                     + str(index) + '.xml'))
+            worksheet._set_xml_writer(
+                self._filename("xl/worksheets/sheet" + str(index) + ".xml")
+            )
             worksheet._assemble_xml_file()
             index += 1
 
@@ -200,8 +201,9 @@ class Packager(object):
             if not worksheet.is_chartsheet:
                 continue
 
-            worksheet._set_xml_writer(self._filename('xl/chartsheets/sheet'
-                                                     + str(index) + '.xml'))
+            worksheet._set_xml_writer(
+                self._filename("xl/chartsheets/sheet" + str(index) + ".xml")
+            )
             worksheet._assemble_xml_file()
             index += 1
 
@@ -214,12 +216,14 @@ class Packager(object):
         for chart in self.workbook.charts:
             # Check that the chart has at least one data series.
             if not chart.series:
-                raise EmptyChartSeries("Chart%d must contain at least one "
-                                       "data series. See chart.add_series()."
-                                       % index)
+                raise EmptyChartSeries(
+                    "Chart%d must contain at least one "
+                    "data series. See chart.add_series()." % index
+                )
 
-            chart._set_xml_writer(self._filename('xl/charts/chart'
-                                                 + str(index) + '.xml'))
+            chart._set_xml_writer(
+                self._filename("xl/charts/chart" + str(index) + ".xml")
+            )
             chart._assemble_xml_file()
             index += 1
 
@@ -230,8 +234,9 @@ class Packager(object):
 
         index = 1
         for drawing in self.workbook.drawings:
-            drawing._set_xml_writer(self._filename('xl/drawings/drawing'
-                                                   + str(index) + '.xml'))
+            drawing._set_xml_writer(
+                self._filename("xl/drawings/drawing" + str(index) + ".xml")
+            )
             drawing._assemble_xml_file()
             index += 1
 
@@ -243,24 +248,30 @@ class Packager(object):
                 continue
             if worksheet.has_vml:
                 vml = Vml()
-                vml._set_xml_writer(self._filename('xl/drawings/vmlDrawing'
-                                                   + str(index) + '.vml'))
-                vml._assemble_xml_file(worksheet.vml_data_id,
-                                       worksheet.vml_shape_id,
-                                       worksheet.comments_list,
-                                       worksheet.buttons_list)
+                vml._set_xml_writer(
+                    self._filename("xl/drawings/vmlDrawing" + str(index) + ".vml")
+                )
+                vml._assemble_xml_file(
+                    worksheet.vml_data_id,
+                    worksheet.vml_shape_id,
+                    worksheet.comments_list,
+                    worksheet.buttons_list,
+                )
                 index += 1
 
             if worksheet.has_header_vml:
                 vml = Vml()
 
-                vml._set_xml_writer(self._filename('xl/drawings/vmlDrawing'
-                                                   + str(index) + '.vml'))
-                vml._assemble_xml_file(worksheet.vml_header_id,
-                                       worksheet.vml_header_id * 1024,
-                                       None,
-                                       None,
-                                       worksheet.header_images_list)
+                vml._set_xml_writer(
+                    self._filename("xl/drawings/vmlDrawing" + str(index) + ".vml")
+                )
+                vml._assemble_xml_file(
+                    worksheet.vml_header_id,
+                    worksheet.vml_header_id * 1024,
+                    None,
+                    None,
+                    worksheet.header_images_list,
+                )
 
                 self._write_vml_drawing_rels_file(worksheet, index)
                 index += 1
@@ -273,8 +284,7 @@ class Packager(object):
                 continue
 
             comment = Comments()
-            comment._set_xml_writer(self._filename('xl/comments'
-                                                   + str(index) + '.xml'))
+            comment._set_xml_writer(self._filename("xl/comments" + str(index) + ".xml"))
             comment._assemble_xml_file(worksheet.comments_list)
             index += 1
 
@@ -286,7 +296,7 @@ class Packager(object):
         if not self.workbook.str_table.count:
             return
 
-        sst._set_xml_writer(self._filename('xl/sharedStrings.xml'))
+        sst._set_xml_writer(self._filename("xl/sharedStrings.xml"))
         sst._assemble_xml_file()
 
     def _write_app_file(self):
@@ -295,10 +305,10 @@ class Packager(object):
         app = App()
 
         # Add the Worksheet heading pairs.
-        app._add_heading_pair(['Worksheets', self.worksheet_count])
+        app._add_heading_pair(["Worksheets", self.worksheet_count])
 
         # Add the Chartsheet heading pairs.
-        app._add_heading_pair(['Charts', self.chartsheet_count])
+        app._add_heading_pair(["Charts", self.chartsheet_count])
 
         # Add the Worksheet parts.
         for worksheet in self.workbook.worksheets():
@@ -314,7 +324,7 @@ class Packager(object):
 
         # Add the Named Range heading pairs.
         if self.named_ranges:
-            app._add_heading_pair(['Named Ranges', len(self.named_ranges)])
+            app._add_heading_pair(["Named Ranges", len(self.named_ranges)])
 
         # Add the Named Ranges parts.
         for named_range in self.named_ranges:
@@ -323,7 +333,7 @@ class Packager(object):
         app._set_properties(properties)
         app.doc_security = self.workbook.read_only
 
-        app._set_xml_writer(self._filename('docProps/app.xml'))
+        app._set_xml_writer(self._filename("docProps/app.xml"))
         app._assemble_xml_file()
 
     def _write_core_file(self):
@@ -332,7 +342,7 @@ class Packager(object):
         core = Core()
 
         core._set_properties(properties)
-        core._set_xml_writer(self._filename('docProps/core.xml'))
+        core._set_xml_writer(self._filename("docProps/core.xml"))
         core._assemble_xml_file()
 
     def _write_metadata_file(self):
@@ -341,7 +351,7 @@ class Packager(object):
             return
 
         metadata = Metadata()
-        metadata._set_xml_writer(self._filename('xl/metadata.xml'))
+        metadata._set_xml_writer(self._filename("xl/metadata.xml"))
         metadata._assemble_xml_file()
 
     def _write_custom_file(self):
@@ -353,7 +363,7 @@ class Packager(object):
             return
 
         custom._set_properties(properties)
-        custom._set_xml_writer(self._filename('docProps/custom.xml'))
+        custom._set_xml_writer(self._filename("docProps/custom.xml"))
         custom._assemble_xml_file()
 
     def _write_content_types_file(self):
@@ -367,26 +377,26 @@ class Packager(object):
         chartsheet_index = 1
         for worksheet in self.workbook.worksheets():
             if worksheet.is_chartsheet:
-                content._add_chartsheet_name('sheet' + str(chartsheet_index))
+                content._add_chartsheet_name("sheet" + str(chartsheet_index))
                 chartsheet_index += 1
             else:
-                content._add_worksheet_name('sheet' + str(worksheet_index))
+                content._add_worksheet_name("sheet" + str(worksheet_index))
                 worksheet_index += 1
 
         for i in range(1, self.chart_count + 1):
-            content._add_chart_name('chart' + str(i))
+            content._add_chart_name("chart" + str(i))
 
         for i in range(1, self.drawing_count + 1):
-            content._add_drawing_name('drawing' + str(i))
+            content._add_drawing_name("drawing" + str(i))
 
         if self.num_vml_files:
             content._add_vml_name()
 
         for i in range(1, self.table_count + 1):
-            content._add_table_name('table' + str(i))
+            content._add_table_name("table" + str(i))
 
         for i in range(1, self.num_comment_files + 1):
-            content._add_comment_name('comments' + str(i))
+            content._add_comment_name("comments" + str(i))
 
         # Add the sharedString rel if there is string data in the workbook.
         if self.workbook.str_table.count:
@@ -404,7 +414,7 @@ class Packager(object):
         if self.workbook.has_metadata:
             content._add_metadata()
 
-        content._set_xml_writer(self._filename('[Content_Types].xml'))
+        content._set_xml_writer(self._filename("[Content_Types].xml"))
         content._assemble_xml_file()
 
     def _write_styles_file(self):
@@ -412,7 +422,7 @@ class Packager(object):
         xf_formats = self.workbook.xf_formats
         palette = self.workbook.palette
         font_count = self.workbook.font_count
-        num_format_count = self.workbook.num_format_count
+        num_formats = self.workbook.num_formats
         border_count = self.workbook.border_count
         fill_count = self.workbook.fill_count
         custom_colors = self.workbook.custom_colors
@@ -420,25 +430,28 @@ class Packager(object):
         has_comments = self.workbook.has_comments
 
         styles = Styles()
-        styles._set_style_properties([
-            xf_formats,
-            palette,
-            font_count,
-            num_format_count,
-            border_count,
-            fill_count,
-            custom_colors,
-            dxf_formats,
-            has_comments])
+        styles._set_style_properties(
+            [
+                xf_formats,
+                palette,
+                font_count,
+                num_formats,
+                border_count,
+                fill_count,
+                custom_colors,
+                dxf_formats,
+                has_comments,
+            ]
+        )
 
-        styles._set_xml_writer(self._filename('xl/styles.xml'))
+        styles._set_xml_writer(self._filename("xl/styles.xml"))
         styles._assemble_xml_file()
 
     def _write_theme_file(self):
         # Write the theme xml file.
         theme = Theme()
 
-        theme._set_xml_writer(self._filename('xl/theme/theme1.xml'))
+        theme._set_xml_writer(self._filename("xl/theme/theme1.xml"))
         theme._assemble_xml_file()
 
     def _write_table_files(self):
@@ -452,8 +465,9 @@ class Packager(object):
 
             for table_props in table_props:
                 table = Table()
-                table._set_xml_writer(self._filename('xl/tables/table'
-                                                     + str(index) + '.xml'))
+                table._set_xml_writer(
+                    self._filename("xl/tables/table" + str(index) + ".xml")
+                )
                 table._set_properties(table_props)
                 table._assemble_xml_file()
                 index += 1
@@ -468,19 +482,16 @@ class Packager(object):
         # Write the _rels/.rels xml file.
         rels = Relationships()
 
-        rels._add_document_relationship('/officeDocument', 'xl/workbook.xml')
+        rels._add_document_relationship("/officeDocument", "xl/workbook.xml")
 
-        rels._add_package_relationship('/metadata/core-properties',
-                                       'docProps/core.xml')
+        rels._add_package_relationship("/metadata/core-properties", "docProps/core.xml")
 
-        rels._add_document_relationship('/extended-properties',
-                                        'docProps/app.xml')
+        rels._add_document_relationship("/extended-properties", "docProps/app.xml")
 
         if self.workbook.custom_properties:
-            rels._add_document_relationship('/custom-properties',
-                                            'docProps/custom.xml')
+            rels._add_document_relationship("/custom-properties", "docProps/custom.xml")
 
-        rels._set_xml_writer(self._filename('_rels/.rels'))
+        rels._set_xml_writer(self._filename("_rels/.rels"))
 
         rels._assemble_xml_file()
 
@@ -493,53 +504,51 @@ class Packager(object):
 
         for worksheet in self.workbook.worksheets():
             if worksheet.is_chartsheet:
-                rels._add_document_relationship('/chartsheet',
-                                                'chartsheets/sheet'
-                                                + str(chartsheet_index)
-                                                + '.xml')
+                rels._add_document_relationship(
+                    "/chartsheet", "chartsheets/sheet" + str(chartsheet_index) + ".xml"
+                )
                 chartsheet_index += 1
             else:
-                rels._add_document_relationship('/worksheet',
-                                                'worksheets/sheet'
-                                                + str(worksheet_index)
-                                                + '.xml')
+                rels._add_document_relationship(
+                    "/worksheet", "worksheets/sheet" + str(worksheet_index) + ".xml"
+                )
                 worksheet_index += 1
 
-        rels._add_document_relationship('/theme', 'theme/theme1.xml')
-        rels._add_document_relationship('/styles', 'styles.xml')
+        rels._add_document_relationship("/theme", "theme/theme1.xml")
+        rels._add_document_relationship("/styles", "styles.xml")
 
         # Add the sharedString rel if there is string data in the workbook.
         if self.workbook.str_table.count:
-            rels._add_document_relationship('/sharedStrings',
-                                            'sharedStrings.xml')
+            rels._add_document_relationship("/sharedStrings", "sharedStrings.xml")
 
         # Add vbaProject if present.
         if self.workbook.vba_project:
-            rels._add_ms_package_relationship('/vbaProject', 'vbaProject.bin')
+            rels._add_ms_package_relationship("/vbaProject", "vbaProject.bin")
 
         # Add the metadata file if required.
         if self.workbook.has_metadata:
-            rels._add_document_relationship('/sheetMetadata', 'metadata.xml')
+            rels._add_document_relationship("/sheetMetadata", "metadata.xml")
 
-        rels._set_xml_writer(self._filename('xl/_rels/workbook.xml.rels'))
+        rels._set_xml_writer(self._filename("xl/_rels/workbook.xml.rels"))
         rels._assemble_xml_file()
 
     def _write_worksheet_rels_files(self):
         # Write data such as hyperlinks or drawings.
         index = 0
         for worksheet in self.workbook.worksheets():
-
             if worksheet.is_chartsheet:
                 continue
 
             index += 1
 
-            external_links = (worksheet.external_hyper_links +
-                              worksheet.external_drawing_links +
-                              worksheet.external_vml_links +
-                              worksheet.external_background_links +
-                              worksheet.external_table_links +
-                              worksheet.external_comment_links)
+            external_links = (
+                worksheet.external_hyper_links
+                + worksheet.external_drawing_links
+                + worksheet.external_vml_links
+                + worksheet.external_background_links
+                + worksheet.external_table_links
+                + worksheet.external_comment_links
+            )
 
             if not external_links:
                 continue
@@ -551,15 +560,15 @@ class Packager(object):
                 rels._add_worksheet_relationship(*link_data)
 
             # Create .rels file such as /xl/worksheets/_rels/sheet1.xml.rels.
-            rels._set_xml_writer(self._filename('xl/worksheets/_rels/sheet'
-                                                + str(index) + '.xml.rels'))
+            rels._set_xml_writer(
+                self._filename("xl/worksheets/_rels/sheet" + str(index) + ".xml.rels")
+            )
             rels._assemble_xml_file()
 
     def _write_chartsheet_rels_files(self):
         # Write the chartsheet .rels files for links to drawing files.
         index = 0
         for worksheet in self.workbook.worksheets():
-
             if not worksheet.is_chartsheet:
                 continue
 
@@ -577,8 +586,9 @@ class Packager(object):
                 rels._add_worksheet_relationship(*link_data)
 
             # Create .rels file such as /xl/chartsheets/_rels/sheet1.xml.rels.
-            rels._set_xml_writer(self._filename('xl/chartsheets/_rels/sheet'
-                                                + str(index) + '.xml.rels'))
+            rels._set_xml_writer(
+                self._filename("xl/chartsheets/_rels/sheet" + str(index) + ".xml.rels")
+            )
             rels._assemble_xml_file()
 
     def _write_drawing_rels_files(self):
@@ -598,8 +608,9 @@ class Packager(object):
                 rels._add_document_relationship(*drawing_data)
 
             # Create .rels file such as /xl/drawings/_rels/sheet1.xml.rels.
-            rels._set_xml_writer(self._filename('xl/drawings/_rels/drawing'
-                                                + str(index) + '.xml.rels'))
+            rels._set_xml_writer(
+                self._filename("xl/drawings/_rels/drawing" + str(index) + ".xml.rels")
+            )
             rels._assemble_xml_file()
 
     def _write_vml_drawing_rels_file(self, worksheet, index):
@@ -613,9 +624,9 @@ class Packager(object):
             rels._add_document_relationship(*drawing_data)
 
         # Create .rels file such as /xl/drawings/_rels/vmlDrawing1.vml.rels.
-        rels._set_xml_writer(self._filename('xl/drawings/_rels/vmlDrawing'
-                                            + str(index)
-                                            + '.vml.rels'))
+        rels._set_xml_writer(
+            self._filename("xl/drawings/_rels/vmlDrawing" + str(index) + ".vml.rels")
+        )
         rels._assemble_xml_file()
 
     def _add_image_files(self):
@@ -625,10 +636,10 @@ class Packager(object):
 
         for image in workbook.images:
             filename = image[0]
-            ext = '.' + image[1]
+            ext = "." + image[1]
             image_data = image[2]
 
-            xml_image_name = 'xl/media/image' + str(index) + ext
+            xml_image_name = "xl/media/image" + str(index) + ext
 
             if not self.in_memory:
                 # In file mode we just write or copy the image file.
@@ -636,7 +647,7 @@ class Packager(object):
 
                 if image_data:
                     # The data is in a byte stream. Write it to the target.
-                    os_file = open(os_filename, mode='wb')
+                    os_file = open(os_filename, mode="wb")
                     os_file.write(image_data.getvalue())
                     os_file.close()
                 else:
@@ -644,8 +655,9 @@ class Packager(object):
 
                     # Allow copies of Windows read-only images to be deleted.
                     try:
-                        os.chmod(os_filename,
-                                 os.stat(os_filename).st_mode | stat.S_IWRITE)
+                        os.chmod(
+                            os_filename, os.stat(os_filename).st_mode | stat.S_IWRITE
+                        )
                     except OSError:
                         pass
             else:
@@ -654,7 +666,7 @@ class Packager(object):
                     # The data is already in a byte stream.
                     os_filename = image_data
                 else:
-                    image_file = open(filename, mode='rb')
+                    image_file = open(filename, mode="rb")
                     image_data = image_file.read()
                     os_filename = BytesIO(image_data)
                     image_file.close()
@@ -671,7 +683,7 @@ class Packager(object):
         if not vba_project:
             return
 
-        xml_vba_name = 'xl/vbaProject.bin'
+        xml_vba_name = "xl/vbaProject.bin"
 
         if not self.in_memory:
             # In file mode we just write or copy the VBA file.
@@ -679,7 +691,7 @@ class Packager(object):
 
             if vba_is_stream:
                 # The data is in a byte stream. Write it to the target.
-                os_file = open(os_filename, mode='wb')
+                os_file = open(os_filename, mode="wb")
                 os_file.write(vba_project.getvalue())
                 os_file.close()
             else:
@@ -691,7 +703,7 @@ class Packager(object):
                 # The data is already in a byte stream.
                 os_filename = vba_project
             else:
-                vba_file = open(vba_project, mode='rb')
+                vba_file = open(vba_project, mode="rb")
                 vba_data = vba_file.read()
                 os_filename = BytesIO(vba_data)
                 vba_file.close()
