@@ -3,16 +3,16 @@
 # Relationships - A class for writing the Excel XLSX Worksheet file.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright 2013-2022, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 # Package imports.
 from . import xmlwriter
 
 # Long namespace strings used in the class.
-schema_root = 'http://schemas.openxmlformats.org'
-package_schema = schema_root + '/package/2006/relationships'
-document_schema = schema_root + '/officeDocument/2006/relationships'
+schema_root = "http://schemas.openxmlformats.org"
+package_schema = schema_root + "/package/2006/relationships"
+document_schema = schema_root + "/officeDocument/2006/relationships"
 
 
 class Relationships(xmlwriter.XMLwriter):
@@ -70,7 +70,7 @@ class Relationships(xmlwriter.XMLwriter):
 
     def _add_ms_package_relationship(self, rel_type, target):
         # Add container relationship to XLSX .rels xml files. Uses MS schema.
-        schema = 'http://schemas.microsoft.com/office/2006/relationships'
+        schema = "http://schemas.microsoft.com/office/2006/relationships"
         rel_type = schema + rel_type
 
         self.relationships.append((rel_type, target, None))
@@ -89,28 +89,33 @@ class Relationships(xmlwriter.XMLwriter):
 
     def _write_relationships(self):
         # Write the <Relationships> element.
-        attributes = [('xmlns', package_schema,)]
+        attributes = [
+            (
+                "xmlns",
+                package_schema,
+            )
+        ]
 
-        self._xml_start_tag('Relationships', attributes)
+        self._xml_start_tag("Relationships", attributes)
 
         for relationship in self.relationships:
             self._write_relationship(relationship)
 
-        self._xml_end_tag('Relationships')
+        self._xml_end_tag("Relationships")
 
     def _write_relationship(self, relationship):
         # Write the <Relationship> element.
         rel_type, target, target_mode = relationship
 
         attributes = [
-            ('Id', 'rId' + str(self.id)),
-            ('Type', rel_type),
-            ('Target', target),
+            ("Id", "rId" + str(self.id)),
+            ("Type", rel_type),
+            ("Target", target),
         ]
 
         self.id += 1
 
         if target_mode:
-            attributes.append(('TargetMode', target_mode))
+            attributes.append(("TargetMode", target_mode))
 
-        self._xml_empty_tag('Relationship', attributes)
+        self._xml_empty_tag("Relationship", attributes)
